#!/bin/bash
if [ "`grep \#TARGET.UID3 src/src.pro`" == "" ]; then
    echo "Seems to be enabled already!"
    exit 1
fi
find . -name "*.pro" -exec sed -i "s/#TARGET.UID3 = 0x20045CF8/TARGET.UID3 = 0x20045CF8/g" {} \;
sed -i "s/DEFINES += EXPIRATION_DATE/#DEFINES += EXPIRATION_DATE/g" ./src/src.pro